*********************************************************

* Legislative Agenda-Setting in Parliamentary Democracies
* Thomas Bräuninger and Marc Debus
* European Journal of Political Research 2009
* Stata do-files for final version
* 19 June 2010

*********************************************************




clear all
version 10
set mem 150m
set more off
use replication_agendasetting_ejpr2009_rev.dta



*************************** create variables *****************************
	
	
	
* Minority government & seat share of government parties

gen minder1 = (g1 <.5)
gen g11 = g1
replace g11 = 0 if g1<.5
* all minority governments are weak except France 1988-93 in 
* economic and foreign policy area
gen minder1_weak = minder1
replace minder1_weak = 0 if ///
  datein < d(17mar1988) | (polcat==1 | polcat==13 | polcat==2)
gen minder1_strong = (minder1 == 1 & minder1_weak == 0) 



* Remaining time in months & pre-election period

gen resttime2 = max_leben_einper - datein
replace resttime2 = resttime2 /30.2
gen preelect = (n_wahldatu-datein < 365) 
for any uk be ge fr: gen Xxpreelect = X * preelect


* Bicameralism

recode typ 1 8 9 11 = 1 else = 0, gen(zustim1)
replace zustim1 = 1 if be & legper < 3
gen brat_threshold = round((asitze+bsitze+csitze+1)/2)
gen abc = .
replace abc = 0 if asitze >= brat_threshold & ge
replace abc = 1 if asitze < brat_threshold & bsitze < brat_threshold & ge
replace abc = 2 if bsitze >= brat_threshold & ge
for num 1/2: gen abcX = 0 \ replace abcX = 1 if abc == X
recode abc 0=0 1/2=1 .=., gen(divid0)
drop abc* brat_threshold


* Divided government

gen div1 = (g2 < .5)
replace div1 = 0 if ge & divid0 == 0
replace div1 = 1 if ge & divid0 == 1
gen div1xzustim1 = div1 * zustim1


* Dummy for Belgium pre/post 1995

gen be_vor95 = 0
replace be_vor95 = 1 if be & (legper==0 | legper==1 | legper==2)
gen be_nach95 = 0
replace be_nach95 = 1 if be & legper>=3 


* Dummies for policy areas

xi I.polcat
gen _Ipolcat_1 = 0
replace _Ipolcat_1 = 1 if polcat == 1
rename _Ipolcat_1 _IpWirtschaft
rename _Ipolcat_2 _IpAussen
rename _Ipolcat_3 _IpSoziales
rename _Ipolcat_8 _IpKommunikation
rename _Ipolcat_9 _IpVerteidigung
rename _Ipolcat_11 _IpBildung
rename _Ipolcat_13 _IpFinanzen
rename _Ipolcat_15 _IpInnen
rename _Ipolcat_16 _IpJustiz
rename _Ipolcat_17 _IpVerkehr
rename _Ipolcat_21 _IpGesundheit
rename _Ipolcat_24 _IpUmweltAgrar
rename _Ipolcat_26 _IpEuropa
rename _Ipolcat_27 _IpRegion
gen _IpAussVert = _IpAussen + _IpVerteidigung 
gen _IpKommBild = _IpKommunikation + _IpBildung 
gen _IpEurReg = _IpEuropa + _IpRegion 
drop _IpVerteidigung _IpAussen _IpBildung _IpKommunikation 
rename _IpRegion nur_IpRegion
rename _IpEuropa nur_IpEuropa
drop if polcat ==.


* Cusack/Engelhardt (2002) general left-right index: veto player distance
* normalize to 0-1

for var vpdi_pjoint: replace X = X/100


* Laver/Hunt policy area-specific index: veto player distance

* economic policy
gen vpdi_policy = 0
replace vpdi_policy = vpdi_LH92economic if _IpWirtschaft == 1 | _IpFinanzen==1 
* social policy (including interior)
replace vpdi_LH92social = 2.05 if fr & datein>=d(17mar1988) & datein<=d(29mar1993)
replace vpdi_policy = vpdi_LH92social if _IpSoziales == 1 | _IpKommBild==1 | _IpJustiz==1 | _IpGesundheit==1 | _IpInnen == 1 
* foreign policy
replace vpdi_LH92ussr = 1.04 if fr & datein>=d(17mar1988) & datein<=d(29mar1993)
replace vpdi_policy = vpdi_LH92ussr if _IpAussVer == 1 
* environmental policy
replace vpdi_LH92environment = 1.57 if fr & datein>=d(17mar1988) & datein<=d(29mar1993)
replace vpdi_policy = vpdi_LH92environment if _IpUmweltAgrar == 1 | _IpVerkehr==1 
* decentralisation policy
replace vpdi_LH92decentral = 0.76 if fr & datein>=d(17mar1988) & datein<=d(29mar1993)
replace vpdi_policy = vpdi_LH92decentral if _IpEurReg == 1 


* Laver/Hunt policy area-specific index: saliences

gen cog_LH92relsal_g = cog_LH92economic_relsal_g
for any Soziales Innen Justiz Gesundheit KommBild : ///
  replace cog_LH92relsal_g = cog_LH92social_relsal_g if _IpX == 1
replace cog_LH92relsal_g = cog_LH92ussr_relsal_g if _IpAussVer == 1
for any Verkehr UmweltAgrar : ///
  replace cog_LH92relsal_g = cog_LH92environment_relsal_g if _IpX == 1
replace cog_LH92relsal_g = cog_LH92decentral_relsal_g if _IpEurReg == 1
gen cog_LH92relsal_o = cog_LH92economic_relsal_o
for any Soziales Innen Justiz Gesundheit KommBild : ///
  replace cog_LH92relsal_o = cog_LH92social_relsal_o if _IpX == 1
replace cog_LH92relsal_o = cog_LH92ussr_relsal_o if _IpAussVer == 1
for any Verkehr UmweltAgrar : ///
  replace cog_LH92relsal_o = cog_LH92environment_relsal_o if _IpX == 1
replace cog_LH92relsal_o = cog_LH92decentral_relsal_o if _IpEurReg == 1
gen saldiff = cog_LH92relsal_g - cog_LH92relsal_o


* General left right index: distances between centers of gravity
* of government and opposition

gen distgovopp = abs(cog_pjoint_g - cog_pjoint_o)


* Laver/Hunt policy area-specific index: distances between centers of gravity
* of government and opposition

gen distgovopp_policy = 0
replace distgovopp_policy = abs(cog_LH92economic_g - cog_LH92economic_o) if _IpWirtschaft == 1 | _IpFinanzen==1 
replace distgovopp_policy = abs(cog_LH92social_g - cog_LH92social_o) if _IpSoziales == 1 | _IpKommBild==1 | _IpJustiz==1 | _IpGesundheit==1 | _IpInnen == 1
replace distgovopp_policy = abs(cog_LH92ussr_g - cog_LH92ussr_o) if _IpAussVer == 1 
replace distgovopp_policy = abs(cog_LH92environment_g - cog_LH92environment_o) if _IpUmweltAgrar == 1 | _IpVerkehr==1 
replace distgovopp_policy = abs(cog_LH92decentral_g - cog_LH92decentral_o) if _IpEurReg == 1 


* Normalize Laver-Hunt data to 0-1

for var vpdi_policy distgovopp_policy: replace X = (X)/19


* Salient issue areas

gen salissues = 0
replace salissues = 1 if (_IpSoziales==1  | _IpInnen==1 | _IpWirtschaft==1) & ge
replace salissues = 1 if (_IpSoziales==1  | _IpInnen==1 | _IpWirtschaft==1 | nur_IpRegion==1 ) & be
replace salissues = 1 if (_IpWirtschaft==1) & (fr | uk)



*************************** transform into clogit format *****************************


sort land datein 
gen nr = _n
expand 4
bysort nr: gen _j = _n
gen choice = _j == initneu
gen gov = _j == 1
gen gop = _j == 2
gen opp = _j == 3
gen mix = _j == 4 

qui foreach x of var ///
    g11 minder1 minder1_strong minder1_weak ///
    vpdi_policy distgovopp_policy vpdi_pjoint distgovopp ///
	preelect bexpreelect ukxpreelect frxpreelect gexpreelect ///
	saldiff salissues ///
	_Ip* nur_Ip* ///
	div1 div1xzustim1 ///
	resttime2 be_nach95 be uk fr ge ///
	cog_LH92relsal_* {
	for Y in var gov gop opp mix: gen YX`x' = Y * `x'
}

save clogit9, replace

* drop 76 Belgian cases whose status is unknown
drop if status ==.




exit


*************************** Conditional logit *****************************


use clogit9, clear


* model 1

clogit choice ///
govXg11 gopXg11 oppXg11 ///
govXminder1 gopXminder1 oppXminder1 ///
govXvpdi_policy gopXvpdi_policy ///
oppXdistgovopp_policy mixXdistgovopp_policy ///
gopXbexpreelect oppXbexpreelect ///
gopXukxpreelect oppXukxpreelect ///
gopXfrxpreelect oppXfrxpreelect ///
gopXgexpreelect oppXgexpreelect ///
govXsaldiff gopXsaldiff oppXsaldiff ///
govX_IpFinanzen ///
govX_IpAussVer ///
govXnur_IpEuropa ///
mixXdiv1 ///
mixXdiv1xzustim1 ///
govXbe_nach95 ///
govXbe gopXbe oppXbe govXfr gopXfr oppXfr govXuk gopXuk oppXuk govXge gopXge oppXge ///
gopXresttime2 oppXresttime2 mixXresttime2 ///
, group (nr) vce(robust) 

outreg using clogit.doc, se replace
drop if e(sample) == 0
estimates stats _all


* model 2: strong and weak minority governments

clogit choice ///
govXg11 gopXg11 oppXg11 ///
govXminder1_strong gopXminder1_strong oppXminder1_strong ///
govXminder1_weak gopXminder1_weak oppXminder1_weak ///
govXvpdi_policy gopXvpdi_policy ///
oppXdistgovopp_policy mixXdistgovopp_policy ///
gopXbexpreelect oppXbexpreelect ///
gopXukxpreelect oppXukxpreelect ///
gopXfrxpreelect oppXfrxpreelect ///
gopXgexpreelect oppXgexpreelect ///
govXsaldiff gopXsaldiff oppXsaldiff ///
govX_IpFinanzen ///
govX_IpAussVer ///
govXnur_IpEuropa ///
mixXdiv1 ///
mixXdiv1xzustim1 ///
govXbe_nach95 ///
govXbe gopXbe oppXbe govXfr gopXfr oppXfr govXuk gopXuk oppXuk govXge gopXge oppXge ///
gopXresttime2 oppXresttime2 mixXresttime2 ///
, group (nr) vce(robust) 

outreg using clogit.doc, se append
estimates stats _all




* model 3: single left-right dimension (pjoint)

clogit choice ///
govXg11 gopXg11 oppXg11 ///
govXminder1 gopXminder1 oppXminder1 ///
govXvpdi_pjoint gopXvpdi_pjoint ///
oppXdistgovopp mixXdistgovopp ///
gopXbexpreelect oppXbexpreelect ///
gopXukxpreelect oppXukxpreelect ///
gopXfrxpreelect oppXfrxpreelect ///
gopXgexpreelect oppXgexpreelect ///
govXsaldiff gopXsaldiff oppXsaldiff ///
govX_IpFinanzen ///
govX_IpAussVer ///
govXnur_IpEuropa ///
mixXdiv1 ///
mixXdiv1xzustim1 ///
govXbe_nach95 ///
govXbe gopXbe oppXbe govXfr gopXfr oppXfr govXuk gopXuk oppXuk govXge gopXge oppXge ///
gopXresttime2 oppXresttime2 mixXresttime2 ///
, group (nr) vce(robust) 

outreg using clogit.doc, se append
estimates stats _all



* model 4: electorally salient issue areas 

clogit choice ///
govXg11 gopXg11 oppXg11 ///
govXminder1 gopXminder1 oppXminder1 ///
govXvpdi_policy gopXvpdi_policy ///
oppXdistgovopp_policy mixXdistgovopp_policy ///
gopXbexpreelect oppXbexpreelect ///
gopXukxpreelect oppXukxpreelect ///
gopXfrxpreelect oppXfrxpreelect ///
gopXgexpreelect oppXgexpreelect ///
govXsalissues gopXsalissues oppXsalissues ///
govX_IpFinanzen ///
govX_IpAussVer ///
govXnur_IpEuropa ///
mixXdiv1 ///
mixXdiv1xzustim1 ///
govXbe_nach95 ///
govXbe gopXbe oppXbe govXfr gopXfr oppXfr govXuk gopXuk oppXuk govXge gopXge oppXge ///
gopXresttime2 oppXresttime2 mixXresttime2 ///
, group (nr) vce(robust) 

outreg using clogit.doc, se append
estimates stats _all




*************** simulation of effects based on model 2 ********************


use clogit9.dta, clear


***** model 2 (re-estimate model with different ordering of variables)

clogit choice ///
govXg11 gopXg11 oppXg11 ///
govXminder1_strong gopXminder1_strong oppXminder1_strong ///
govXvpdi_policy gopXvpdi_policy ///
oppXdistgovopp_policy mixXdistgovopp_policy ///
gopXbexpreelect oppXbexpreelect ///
gopXukxpreelect oppXukxpreelect ///
gopXfrxpreelect oppXfrxpreelect ///
gopXgexpreelect oppXgexpreelect ///
govXsaldiff gopXsaldiff oppXsaldiff ///
govX_IpFinanzen ///
govX_IpAussVer ///
govXnur_IpEuropa ///
mixXdiv1 ///
mixXdiv1xzustim1 ///
govXbe_nach95 ///
govXbe gopXbe oppXbe govXfr gopXfr oppXfr govXuk gopXuk oppXuk govXge gopXge oppXge ///
gopXresttime2 oppXresttime2 mixXresttime2 ///
govXminder1_weak gopXminder1_weak oppXminder1_weak ///
, group (nr) vce(robust) 

est store model1
drop if e(sample)==0

gen vp = vpdi_policy
gen di = distgovopp_policy
gen gg = g1
gen sa = saldiff
gen rt = resttime2



***** simulation of confidence bands

foreach v of var vp di gg sa {

qui sum `v', detail
scalar rp5 = r(p5)
scalar rp95 = r(p95)
scalar step_ = (rp95 - rp5)/20

for var saldiff resttime2 g1 vpdi_policy distgovopp_policy: ///
  qui sum X \ scalar h_X = r(mean)

preserve
drawnorm b1-b45, n(10000) means(e(b)) cov(e(V)) clear

postutil clear
postfile mypost a prob_hat1 lo1 hi1 prob_hat2 lo2 hi2 prob_hat3 lo3 hi3 prob_hat4 lo4 hi4 ///
  using sim_`v'_band , replace

qui foreach a of numlist 0/20 {  

    qui gen x_bh1 = b1*h_g1 + b7*h_vpdi_policy + b19*h_saldiff + b28
    qui gen x_bh2 = b2*h_g1 + b8*h_vpdi_policy + b20*h_saldiff + b40*h_resttime2 + b29
    qui gen x_bh3 = b3*h_g1 + b9*h_distgovopp_policy + b21*h_saldiff + b41*h_resttime2 + b30
    qui gen x_bh4 = b10*h_distgovopp_policy + b25 + b42*h_resttime2

    if "`v'" == "vp" {
	qui replace x_bh1 = x_bh1 - b7*h_vpdi_policy + b7*(rp5+`a'*step_) 
    	qui replace x_bh2 = x_bh2 - b8*h_vpdi_policy + b8*(rp5+`a'*step_) 
    } 

    if "`v'" == "di" {
	qui replace x_bh3 = x_bh3 - b9*h_distgovopp_policy + b9*(rp5+`a'*step_)
    	qui replace x_bh4 = x_bh4 - b10*h_distgovopp_policy + b10*(rp5+`a'*step_)
    } 

    if "`v'" == "gg" {
	qui replace x_bh1 = x_bh1 - b1*h_g1 + b1*(rp5+`a'*step_)
	qui replace x_bh2 = x_bh2 - b2*h_g1 + b2*(rp5+`a'*step_)
    	qui replace x_bh3 = x_bh3 - b3*h_g1 + b3*(rp5+`a'*step_)
    } 

    if "`v'" == "sa" {
	qui replace x_bh1 = x_bh1 - b19*h_saldiff + b19*(rp5+`a'*step_)
	qui replace x_bh2 = x_bh2 - b20*h_saldiff + b20*(rp5+`a'*step_)
    	qui replace x_bh3 = x_bh3 - b21*h_saldiff + b21*(rp5+`a'*step_)
    } 

    qui {
    for num 1/4: gen ex_bhX = exp(x_bhX)
    gen sumex = ex_bh1+ex_bh2+ex_bh3+ex_bh4
    for num 1/4: gen probX = ex_bhX / sumex
    
    for num 1/4: egen probhatX = mean(probX)
    
    tempname prob_hat1 lo1 hi1 prob_hat2 lo2 hi2 prob_hat3 lo3 hi3 prob_hat4 lo4 hi4 

    foreach n of num 1/4 {
		_pctile prob`n', p(5,95) 
		scalar `lo`n'' = r(r1)
		scalar `hi`n'' = r(r2)  
    }
   
    scalar `prob_hat1' = probhat1
    scalar `prob_hat2' = probhat2
    scalar `prob_hat3' = probhat3
    scalar `prob_hat4' = probhat4
    
    post mypost (`a') (`prob_hat1') (`lo1') (`hi1') (`prob_hat2') (`lo2') (`hi2') ///
	          (`prob_hat3') (`lo3') (`hi3') (`prob_hat4') (`lo4') (`hi4')
 
    drop x_bh? ex_bh? sumex prob? probhat?
    }

    }

postclose mypost

restore

}


***** simulation of change in prob for dummies

est restore model1

for var saldiff resttime2 g1 vpdi_policy distgovopp_policy: ///
  qui sum X \ scalar h_X = r(mean)

qui foreach v of any minder1_strong minder1_weak ///
  bexpreelect ukxpreelect frxpreelect gexpreelect ///
  _IpFinanzen nur_IpEuropa _IpAussVer div1 div1xzustim1 be_nach95 uk fr ge {

preserve
drawnorm b1-b45, n(20000) means(e(b)) cov(e(V)) clear

postutil clear
postfile mypost str30 v prob_hat1 diff_hat1 lo1 hi1 prob_hat2 diff_hat2 lo2 hi2 ///
  prob_hat3 diff_hat3 lo3 hi3 prob_hat4 diff_hat4 lo4 hi4 ///
  using sim_`v' , replace

    qui gen x_bh1 = b1*h_g1 + b7*h_vpdi_policy + b19*h_saldiff + b28
    qui gen x_bh2 = b2*h_g1 + b8*h_vpdi_policy + b20*h_saldiff + b40*h_resttime2 + b29
    qui gen x_bh3 = b3*h_g1 + b9*h_distgovopp_policy + b21*h_saldiff + b41*h_resttime2 + b30
    qui gen x_bh4 = b10*h_distgovopp_policy + b25 + b42*h_resttime2

    for num 1/4: gen x_bhX_ = x_bhX

    if "`v'" == "minder1_strong" {
	qui replace x_bh1_ = x_bh1 + b4 - b1*h_g1
    	qui replace x_bh2_ = x_bh2 + b5 - b2*h_g1 
    	qui replace x_bh3_ = x_bh3 + b6 - b3*h_g1 
    } 

    if "`v'" == "minder1_weak" {
	qui replace x_bh1_ = x_bh1 + b43 - b1*h_g1
    	qui replace x_bh2_ = x_bh2 + b44 - b2*h_g1 
    	qui replace x_bh3_ = x_bh3 + b45 - b3*h_g1 
    } 

    if "`v'" == "bexpreelect" {
    	qui replace x_bh2_ = x_bh2 + b11
    	qui replace x_bh3_ = x_bh3 + b12
    } 

    if "`v'" == "ukxpreelect" {
    	qui replace x_bh2_ = x_bh2 + b13
    	qui replace x_bh3_ = x_bh3 + b14
    } 

    if "`v'" == "frxpreelect" {
    	qui replace x_bh2_ = x_bh2 + b15
    	qui replace x_bh3_ = x_bh3 + b16
    } 

    if "`v'" == "gexpreelect" {
    	qui replace x_bh2_ = x_bh2 + b17
    	qui replace x_bh3_ = x_bh3 + b18
    } 

    if "`v'" == "_IpFinanzen" {
    	qui replace x_bh1_ = x_bh1 + b22
    } 

    if "`v'" == "nur_IpEuropa" {
    	qui replace x_bh1_ = x_bh1 + b23
    } 

    if "`v'" == "_IpAussVer" {
    	qui replace x_bh1_ = x_bh1 + b24
    } 

    if "`v'" == "div1" {
    	qui replace x_bh4_ = x_bh4 - b25
    } 

    if "`v'" == "div1xzustim1" {
    	qui replace x_bh4_ = x_bh4 + b26
    } 

    if "`v'" == "be_nach95" {
    	qui replace x_bh1_ = x_bh1 + b27
    } 

    if "`v'" == "fr" {
	qui replace x_bh1_ = x_bh1 - b28 + b31
    	qui replace x_bh2_ = x_bh2 - b29 + b32 
    	qui replace x_bh3_ = x_bh3 - b39 + b33 
    } 

    if "`v'" == "uk" {
	qui replace x_bh1_ = x_bh1 - b28 + b34
    	qui replace x_bh2_ = x_bh2 - b29 + b35 
    	qui replace x_bh3_ = x_bh3 - b30 + b36 
    } 

    if "`v'" == "ge" {
	qui replace x_bh1_ = x_bh1 - b28 + b37
    	qui replace x_bh2_ = x_bh2 - b29 + b38 
    	qui replace x_bh3_ = x_bh3 - b30 + b39 
    } 

    qui {
    for num 1/4: gen ex_bhX = exp(x_bhX) \ gen ex_bhX_ = exp(x_bhX_)
    gen sumex = ex_bh1+ex_bh2+ex_bh3+ex_bh4
    gen sumex_ = ex_bh1_+ex_bh2_+ex_bh3_+ex_bh4_
    for num 1/4: gen probX = ex_bhX / sumex \ gen probX_ = ex_bhX_ / sumex_
    for num 1/4: gen diffX = probX_ - probX
    
    for num 1/4: egen probhatX = mean(probX) \ egen probhatX_ = mean(probX_)
    for num 1/4: egen diffhatX = mean(diffX)
    
    tempname prob_hat1 diff_hat1 lo1 hi1 prob_hat2 diff_hat2 lo2 hi2 ///
      prob_hat3 diff_hat3 lo3 hi3 prob_hat4 diff_hat4 lo4 hi4 

    foreach n of num 1/4 {
		_pctile diff`n', p(2.5,97.5) 
		scalar `lo`n'' = r(r1)
		scalar `hi`n'' = r(r2)  
    }
   
    scalar `prob_hat1' = probhat1
    scalar `prob_hat2' = probhat2
    scalar `prob_hat3' = probhat3
    scalar `prob_hat4' = probhat4

    scalar `diff_hat1' = diffhat1
    scalar `diff_hat2' = diffhat2
    scalar `diff_hat3' = diffhat3
    scalar `diff_hat4' = diffhat4
    
    post mypost ("`v'") (`prob_hat1') (`diff_hat1') (`lo1') (`hi1') (`prob_hat2') ///
	(`diff_hat2') (`lo2') (`hi2') (`prob_hat3') (`diff_hat3') ///
	(`lo3') (`hi3') (`prob_hat4') (`diff_hat4') (`lo4') (`hi4')
 
    drop x_bh* ex_bh* sumex* prob? probhat? diff? diffhat?

    }

postclose mypost

restore

}


***** simulation of change in probabilities for continuous variables

est restore model1

for var saldiff resttime2 g1 vpdi_policy distgovopp_policy: ///
  qui sum X \ scalar h_X = r(mean)


qui foreach v of any vp di gg sa rt {

qui sum `v', detail
scalar rp5 = r(p5)
scalar rp95 = r(p95)

preserve
drawnorm b1-b45, n(10000) means(e(b)) cov(e(V)) clear

postutil clear
postfile mypost str30 v prob_hat1 diff_hat1 lo1 hi1 prob_hat2 diff_hat2 lo2 hi2 ///
  prob_hat3 diff_hat3 lo3 hi3 prob_hat4 diff_hat4 lo4 hi4 ///
  using sim_`v' , replace

    qui gen x_bh1 = b1*h_g1 + b7*h_vpdi_policy + b19*h_saldiff + b28
    qui gen x_bh2 = b2*h_g1 + b8*h_vpdi_policy + b20*h_saldiff + b40*h_resttime2 + b29
    qui gen x_bh3 = b3*h_g1 + b9*h_distgovopp_policy + b21*h_saldiff + b41*h_resttime2 + b30
    qui gen x_bh4 = b10*h_distgovopp_policy + b25 + b42*h_resttime2

    for num 1/4: gen x_bhX_ = x_bhX

    if "`v'" == "vp" {
	qui replace x_bh1 = x_bh1 - b7*h_vpdi_policy + b7*(rp5) 
    	qui replace x_bh2 = x_bh2 - b8*h_vpdi_policy + b8*(rp5) 
	qui replace x_bh1_ = x_bh1_ - b7*h_vpdi_policy + b7*(rp95) 
    	qui replace x_bh2_ = x_bh2_ - b8*h_vpdi_policy + b8*(rp95) 
    } 

    if "`v'" == "di" {
	qui replace x_bh3 = x_bh3 - b9*h_distgovopp_policy + b9*(rp5)
    	qui replace x_bh4 = x_bh4 - b10*h_distgovopp_policy + b10*(rp5)
	qui replace x_bh3_ = x_bh3_ - b9*h_distgovopp_policy + b9*(rp95)
    	qui replace x_bh4_ = x_bh4_ - b10*h_distgovopp_policy + b10*(rp95)
    } 

    if "`v'" == "gg" {
	qui replace x_bh1 = x_bh1 - b1*h_g1 + b1*(rp5)
	qui replace x_bh2 = x_bh2 - b2*h_g1 + b2*(rp5)
    	qui replace x_bh3 = x_bh3 - b3*h_g1 + b3*(rp5)
	qui replace x_bh1_ = x_bh1_ - b1*h_g1 + b1*(rp95)
	qui replace x_bh2_ = x_bh2_ - b2*h_g1 + b2*(rp95)
    	qui replace x_bh3_ = x_bh3_ - b3*h_g1 + b3*(rp95)
    } 

    if "`v'" == "sa" {
	qui replace x_bh1 = x_bh1 - b19*h_saldiff + b19*(rp5)
	qui replace x_bh2 = x_bh2 - b20*h_saldiff + b20*(rp5)
    	qui replace x_bh3 = x_bh3 - b21*h_saldiff + b21*(rp5)
	qui replace x_bh1_ = x_bh1_ - b19*h_saldiff + b19*(rp95)
	qui replace x_bh2_ = x_bh2_ - b20*h_saldiff + b20*(rp95)
    	qui replace x_bh3_ = x_bh3_ - b21*h_saldiff + b21*(rp95)
    } 

    if "`v'" == "rt" {
	qui replace x_bh2 = x_bh2 - b40*h_resttime2 + b40*(rp5)
    	qui replace x_bh3 = x_bh3 - b41*h_resttime2 + b41*(rp5)
	qui replace x_bh4 = x_bh4 - b42*h_resttime2 + b42*(rp5)
	qui replace x_bh2_ = x_bh2_ - b40*h_resttime2 + b40*(rp95)
    	qui replace x_bh3_ = x_bh3_ - b41*h_resttime2 + b41*(rp95)
	qui replace x_bh4_ = x_bh4_ - b42*h_resttime2 + b42*(rp95)
    } 

    qui {
    for num 1/4: gen ex_bhX = exp(x_bhX) \ gen ex_bhX_ = exp(x_bhX_)
    gen sumex = ex_bh1+ex_bh2+ex_bh3+ex_bh4
    gen sumex_ = ex_bh1_+ex_bh2_+ex_bh3_+ex_bh4_
    for num 1/4: gen probX = ex_bhX / sumex \ gen probX_ = ex_bhX_ / sumex_
    for num 1/4: gen diffX = probX_ - probX
    
    for num 1/4: egen probhatX = mean(probX) \ egen probhatX_ = mean(probX_)
    for num 1/4: egen diffhatX = mean(diffX)
    
    tempname prob_hat1 diff_hat1 lo1 hi1 prob_hat2 diff_hat2 lo2 hi2 ///
      prob_hat3 diff_hat3 lo3 hi3 prob_hat4 diff_hat4 lo4 hi4 

    foreach n of num 1/4 {
		_pctile diff`n', p(2.5,97.5) 
		scalar `lo`n'' = r(r1)
		scalar `hi`n'' = r(r2)  
    }
   
    scalar `prob_hat1' = probhat1
    scalar `prob_hat2' = probhat2
    scalar `prob_hat3' = probhat3
    scalar `prob_hat4' = probhat4

    scalar `diff_hat1' = diffhat1
    scalar `diff_hat2' = diffhat2
    scalar `diff_hat3' = diffhat3
    scalar `diff_hat4' = diffhat4
    
    post mypost ("`v'") (`prob_hat1') (`diff_hat1') (`lo1') (`hi1') (`prob_hat2') ///
	(`diff_hat2') (`lo2') (`hi2') (`prob_hat3') (`diff_hat3') ///
	(`lo3') (`hi3') (`prob_hat4') (`diff_hat4') (`lo4') (`hi4')
 
    drop x_bh* ex_bh* sumex* prob? probhat? diff? diffhat?

    }

postclose mypost

restore

}


***** print base probablity and changes

use sim_minder1_strong, clear
foreach v of any minder1_weak bexpreelect ukxpreelect frxpreelect gexpreelect ///
  _IpFinanzen nur_IpEuropa _IpAussVer div1 div1xzustim1 be_nach95 fr uk ge vp di gg sa rt {
	append using sim_`v'
erase sim_`v'.dta
}
save simulated_probabilities0, replace
erase sim_minder1_strong.dta


for num 1/4: list v prob_hatX diff_hatX loX hiX 

for num 1/4: gen sigX = loX*hiX
foreach x of any gg minder1_strong minder1_weak vp di ///
  bexpreelect ukxpreelect frxpreelect gexpreelect sa ///
  _IpFinanzen nur_IpEuropa _IpAussVer ///
  div1 div1xzustim1 be_nach95 uk fr ge rt {
	di "`v'" _c
	cap for num 1/4: qui sum diff_hatX if v=="`x'" \ scalar pX=r(mean) 
      foreach X of num 1/4 {
		di %9.3f p`X' _c 
            qui sum sig`X' if v=="`x'" 
		if r(mean)>0 {
			di "*" _c
		}
		else {
			di " " _c
		}
	}
	noi di " "
}
drop sig?



************************** IIA test *********************

***** test procedure developed by Martin / Stevenson 2001, AJPS
*syntax "iiatest av uvs, per(90) gid(byvar) reps(50)"
capture program drop iiatest
program define iiatest
	syntax varlist [if], per(integer) gid(varname) reps(integer)
	preserve
	matrix CHLIST=J(`reps',1,0)
	matrix DFLIST=J(`reps',1,0)
	matrix PRLIST=J(`reps',1,0)
	tokenize `varlist'
	local realg "`1'"
	macro shift 1
	local ivs "`*'"
	clogit `realg' `ivs' `if', group(`gid')
	hausman, save
	local i `reps'
	while `i' > 0 {
		tempfile master
		qui save `master'
		display "`i' " _c
		sample `per' if `realg'==0 & minder1==0, by(`gid')
		clogit `realg' `ivs' `if', group(`gid')
		hausman, alleqs less		
		mat DFLIST[`i',1]=`r(df)'
		if `r(chi2)' > 0 {
			mat PRLIST[`i',1]=chiprob(`r(df)',`r(chi2)')
			mat CHLIST[`i',1]=`r(chi2)'
		}
		else if `r(chi2)' <= 0 {
			mat PRLIST[`i',1]=0.99
			mat CHLIST[`i',1]=0.0
		}
		local i=`i'-1
		use `master', clear

	}

*mat list CHLIST
mat CHMAT=diag(CHLIST)
scalar avstat=trace(CHMAT)/`reps'
scalar list avstat

*mat list DFLIST
mat DFMAT=diag(DFLIST)
scalar avdf=trace(DFMAT)/`reps'
scalar list avdf

*mat list PRLIST
mat PRMAT=diag(PRLIST)
scalar avpr=trace(PRMAT)/`reps'
scalar list avpr

end


***** IIA-test for data

use clogit9.dta, clear

* model 1
iiatest choice ///
govXg11 gopXg11 oppXg11 ///
govXminder1 gopXminder1 oppXminder1 ///
govXvpdi_policy gopXvpdi_policy ///
oppXdistgovopp_policy mixXdistgovopp_policy ///
gopXbexpreelect oppXbexpreelect ///
gopXukxpreelect oppXukxpreelect ///
gopXfrxpreelect oppXfrxpreelect ///
gopXgexpreelect oppXgexpreelect ///
govXsaldiff gopXsaldiff oppXsaldiff ///
govX_IpFinanzen ///
govX_IpAussVer ///
govXnur_IpEuropa ///
mixXdiv1 ///
mixXdiv1xzustim1 ///
govXbe_nach95 ///
govXbe gopXbe oppXbe govXfr gopXfr oppXfr govXuk gopXuk oppXuk govXge gopXge oppXge ///
gopXresttime2 oppXresttime2 mixXresttime2 ///
, per(90) gid(nr) reps(50)

* model 2
iiatest choice ///
govXg11 gopXg11 oppXg11 ///
govXminder1_strong gopXminder1_strong oppXminder1_strong ///
govXminder1_weak gopXminder1_weak oppXminder1_weak ///
govXvpdi_pjoint gopXvpdi_pjoint ///
oppXdistgovopp mixXdistgovopp ///
gopXbexpreelect oppXbexpreelect ///
gopXukxpreelect oppXukxpreelect ///
gopXfrxpreelect oppXfrxpreelect ///
gopXgexpreelect oppXgexpreelect ///
govXsaldiff gopXsaldiff oppXsaldiff ///
govX_IpFinanzen ///
govX_IpAussVer ///
govXnur_IpEuropa ///
mixXdiv1 ///
mixXdiv1xzustim1 ///
govXbe_nach95 ///
govXbe gopXbe oppXbe govXfr gopXfr oppXfr govXuk gopXuk oppXuk govXge gopXge oppXge ///
gopXresttime2 oppXresttime2 mixXresttime2 ///
, per(90) gid(nr) reps(50)

* model 3
iiatest choice ///
govXg11 gopXg11 oppXg11 ///
govXminder1 gopXminder1 oppXminder1 ///
govXvpdi_policy gopXvpdi_policy ///
oppXdistgovopp mixXdistgovopp ///
gopXbexpreelect oppXbexpreelect ///
gopXukxpreelect oppXukxpreelect ///
gopXfrxpreelect oppXfrxpreelect ///
gopXgexpreelect oppXgexpreelect ///
govXsalissues gopXsalissues oppXsalissues ///
govX_IpFinanzen ///
govX_IpAussVer ///
govXnur_IpEuropa ///
mixXdiv1 ///
mixXdiv1xzustim1 ///
govXbe_nach95 ///
govXbe gopXbe oppXbe govXfr gopXfr oppXfr govXuk gopXuk oppXuk govXge gopXge oppXge ///
gopXresttime2 oppXresttime2 mixXresttime2 ///
, per(90) gid(nr) reps(50)

* model 4
iiatest choice ///
govXg11 gopXg11 oppXg11 ///
govXminder1 gopXminder1 oppXminder1 ///
govXvpdi_policy gopXvpdi_policy ///
oppXdistgovopp_policy mixXdistgovopp_policy ///
gopXbexpreelect oppXbexpreelect ///
gopXukxpreelect oppXukxpreelect ///
gopXfrxpreelect oppXfrxpreelect ///
gopXgexpreelect oppXgexpreelect ///
govXsalissues gopXsalissues oppXsalissues ///
govX_IpFinanzen ///
govX_IpAussVer ///
govXnur_IpEuropa ///
mixXdiv1 ///
mixXdiv1xzustim1 ///
govXbe_nach95 ///
govXbe gopXbe oppXbe govXfr gopXfr oppXfr govXuk gopXuk oppXuk govXge gopXge oppXge ///
gopXresttime2 oppXresttime2 mixXresttime2 ///
, per(90) gid(nr) reps(50)

